/*

  This file is a part of GRALESHELL, a program to facilitate the simulation
  and inversion of gravitational lenses, based on the GRALE library.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#ifndef GRALESHELLGAPARAMS_H

#define GRALESHELLGAPARAMS_H

#include <mogal/geneticalgorithm.h>
#include <string>

class GraleShellGAParams : public mogal::GeneticAlgorithmParams
{
public:
	GraleShellGAParams()												{ saveIntermediate = false; intprefix = std::string("intlens_"); saveAll = false; saveprefix = std::string("savedlens_"); }
	GraleShellGAParams(double beta_, bool elitism_, bool includebest_, double cross_, 
			   bool saveIntermediate_, const std::string &intprefix_, bool saveAll_, const std::string &saveprefix_) : mogal::GeneticAlgorithmParams(beta_, elitism_, includebest_, cross_) 
															{ saveIntermediate = saveIntermediate_; intprefix = intprefix_; saveAll = saveAll_; saveprefix = saveprefix_; }
	~GraleShellGAParams()												{ }
	bool SaveIntermediate() const											{ return saveIntermediate; }
	std::string GetIntermediatePrefix() const									{ return intprefix; }
	bool SaveAll() const												{ return saveAll; }
	std::string GetSavePrefix() const										{ return saveprefix; }
private:
	bool saveIntermediate;
	std::string intprefix;
	bool saveAll;
	std::string saveprefix;
};

#endif // GRALESHELLGAPARAMS_H

